[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Bacula-devel] Weird!
Hi Commiters,
the spelling of the word weird is weird. Isn't that weird? :)
Ytpo-fixing patch attached.
Bastian
--
Collax GmbH . Burkheimer Straße 3 . 79111 Freiburg . Germany
p: +49 (0) 761-45684-24
f: +49 (0) 761-45684-10 www.collax.com
Geschäftsführer: William K. Hite / Boris Nalbach
AG München HRB 158898 . Ust.-IdNr: DE 814464942
\ Sleep is a poor substitute for caffeine.
Index: src/stored/bextract.c
===================================================================
--- src/stored/bextract.c (Revision 7583)
+++ src/stored/bextract.c (Arbeitskopie)
@@ -482,7 +482,7 @@
break;
default:
- /* If extracting, wierd stream (not 1 or 2), close output file anyway */
+ /* If extracting, weird stream (not 1 or 2), close output file anyway */
if (extract) {
if (!is_bopen(&bfd)) {
Emsg0(M_ERROR, 0, _("Logic error output file should be open but is not.\n"));
-------------------------------------------------------------------------
This SF.Net email is sponsored by the Moblin Your Move Developer's challenge
Build the coolest Linux based applications with Moblin SDK & win great prizes
Grand prize is a trip for two to an Open Source event anywhere in the world
http://moblin-contest.org/redirect.php?banner_id=100&url=/
_______________________________________________
Bacula-devel mailing list
Bacula-devel@xxxxxxxxxxxxxxxxxxxxx
https://lists.sourceforge.net/lists/listinfo/bacula-devel
This mailing list archive is a service of Copilot Consulting.
Index: src/filed/restore.c
===================================================================
--- src/filed/restore.c (Revision 7583)
+++ src/filed/restore.c (Arbeitskopie)
@@ -657,9 +657,9 @@
break;
default:
/* If extracting, wierd stream (not 1 or 2), close output file anyway */
if (extract) {
- Dmsg1(130, "Found wierd stream %d\n", rctx.stream);
+ Dmsg1(130, "Found weird stream %d\n", rctx.stream);
if (rctx.size > 0 && !is_bopen(&rctx.bfd)) {
Jmsg0(jcr, M_ERROR, 0, _("Logic error: output file should be open\n"));
}
@@ -657,9 +657,9 @@
break;
default:
- /* If extracting, wierd stream (not 1 or 2), close output file anyway */
+ /* If extracting, weird stream (not 1 or 2), close output file anyway */
if (extract) {